Package 'OSCA.advanced'
| Title: |
Advanced Single-Cell Analysis |
| Description: |
Deploys the advanced analysis chapters for the
"Orchestrating Single Cell Analysis with Bioconductor" book.
This describes the more complex steps of a single-cell RNA-seq
analysis ranging from doublet detection, cell cycle assignment,
specific steps for processing droplet data, nuclei-specific
analyses, trajectory analyses, integrated analyses with protein
abundances, and interactive visualization. It also elaborates
on some of the basic analysis steps, focusing on alternative
strategies and theoretical considerations. It is intended for
readers who are already familiar with basic single-cell
analyses, possibly after reading some of the prior books in
this collection. |
| Authors: |
Robert Amezquita [aut],
Aaron Lun [aut],
Stephanie Hicks [aut],
Raphael Gottardo [aut],
Ludwig Geistlinger [cre],
Peter Hickey [ctb] |
| Maintainer: |
Ludwig Geistlinger <[email protected]> |
| License: |
CC BY 4.0 |
| Version: |
1.21.0 |
| Built: |
2026-05-28 15:08:18 UTC |
| Source: |
https://github.com/bioc/OSCA.advanced |
Help Index